@@ -147,6 +147,11 @@ XineEngine::init()
 
    xine_init( m_xine );
 
+#if XINE_MAJOR_VERSION > 1 || (XINE_MAJOR_VERSION == 1 && XINE_MINOR_VERSION > 2) || \
+   (XINE_MAJOR_VERSION == 1 && XINE_MINOR_VERSION == 2 && XINE_SUB_VERSION >= 10)
+   xine_register_plugins( m_xine, scope_plugin_info );
+#endif
+
    makeNewStream();
 
    #ifndef XINE_SAFE_MODE
@@ -189,13 +194,17 @@ XineEngine::makeNewStream()
          &XineEngine::XineEventListener,
          (void*)this );
 
-   #ifndef XINE_SAFE_MODE
-   //implemented in xine-scope.h
+#ifndef XINE_SAFE_MODE
+#if XINE_MAJOR_VERSION > 1 || (XINE_MAJOR_VERSION == 1 && XINE_MINOR_VERSION > 2) || \
+   (XINE_MAJOR_VERSION == 1 && XINE_MINOR_VERSION == 2 && XINE_SUB_VERSION >= 10)
+   m_post = xine_post_init( m_xine, "amarok-scope", 1, &m_audioPort, NULL );
+#else
    m_post = scope_plugin_new( m_xine, m_audioPort );
+#endif
 
    xine_set_param( m_stream, XINE_PARAM_METRONOM_PREBUFFER, 6000 );
    xine_set_param( m_stream, XINE_PARAM_IGNORE_VIDEO, 1 );
-   #endif
+#endif
 #ifdef XINE_PARAM_EARLY_FINISHED_EVENT
     if ( xine_check_version(1,1,1) && !(m_xfadeLength > 0) ) {
         // enable gapless playback
@@ -260,14 +269,14 @@ XineEngine::load( const KURL &url, bool isStream )
    {
       debug() << "After xine_open() *****" << endl;
 
-      #ifndef XINE_SAFE_MODE
+#ifndef XINE_SAFE_MODE
       //we must ensure the scope is pruned of old buffers
       timerEvent( 0 );
 
       xine_post_out_t *source = xine_get_audio_source( m_stream );
       xine_post_in_t  *target = (xine_post_in_t*)xine_post_input( m_post, const_cast<char*>("audio in") );
       xine_post_wire( source, target );
-      #endif
+#endif
 
       playlistChanged();
 
@@ -719,7 +728,7 @@ XineEngine::scope()
        return m_scope;
 
     MyNode* const myList         = scope_plugin_list( m_post );
-    metronom_t* const myMetronom = scope_plugin_metronom( m_post );
+    const int64_t pts_per_smpls  = scope_plugin_pts_per_smpls( m_post );
     const int myChannels         = scope_plugin_channels( m_post );
     int scopeidx = 0;
 
@@ -744,7 +753,7 @@ XineEngine::scope()
         diff  = m_currentVpts;
         diff -= best_node->vpts;
         diff *= 1<<16;
-        diff /= myMetronom->pts_per_smpls;
+        diff /= pts_per_smpls;
 
         const int16_t*
         data16  = best_node->mem;
@@ -787,7 +796,6 @@ XineEngine::timerEvent( TQTimerEvent* )
       return;
 
    //here we prune the buffer list regularly
-
    MyNode *myList = scope_plugin_list( m_post );
 
    if ( ! myList ) return;
