@@ -6,17 +6,17 @@
 #ifndef AMAROK_HTMLVIEW_H
 #define AMAROK_HTMLVIEW_H
 
-#include <khtml_events.h>
-#include <khtml_part.h>
-#include <khtmlview.h>
+#include <tdehtml_events.h>
+#include <tdehtml_part.h>
+#include <tdehtmlview.h>
 
-class KAction;
+class TDEAction;
 class KTempFile;
 
-class HTMLView : public KHTMLPart
+class HTMLView : public TDEHTMLPart
 {
     Q_OBJECT
-  TQ_OBJECT
+  
 
     public:
         HTMLView( TQWidget *parentWidget = 0, const char *widgetname = 0, const bool DNDEnabled = false, const bool JScriptEnabled = true );
@@ -33,8 +33,8 @@ class HTMLView : public KHTMLPart
         static KTempFile *m_shadowGradientImage;
         static int m_instances;
 
-        KAction *m_selectAll;
-        KAction *m_copy;
+        TDEAction *m_selectAll;
+        TDEAction *m_copy;
 
     private slots:
         void enableCopyAction();
