@@ -25,10 +25,7 @@
 #ifndef AMAROK_IPODMEDIADEVICE_H
 #define AMAROK_IPODMEDIADEVICE_H
 
-extern "C" {
 #include <gpod/itdb.h>
-}
-
 
 #include "mediabrowser.h"
 
