@@ -11,6 +11,7 @@
 #define PLAYLISTBROWSER_H
 
 #include "amarokconfig.h"
+#include "amarok_export.h"
 #include "playlistbrowseritem.h"
 #include "podcastsettings.h"
 
@@ -42,8 +43,8 @@ class PlaylistTrackItem;
 
 class PlaylistBrowser : public TQVBox
 {
-        Q_OBJECT
-  
+    Q_OBJECT
+
     friend class DynamicMode;
     friend class PlaylistBrowserView;
 
@@ -73,7 +74,7 @@ class PlaylistBrowser : public TQVBox
         int  loadPlaylist( const TQString &playlist, bool force=false );
 
         void addPodcast( TQListViewItem *parent = 0 );
-        void addPodcast( const KURL &url, TQListViewItem *parent = 0 );
+        LIBAMAROK_EXPORT void addPodcast( const KURL &url, TQListViewItem *parent = 0 );
         void loadPodcastsFromDatabase( PlaylistCategory *p = 0 );
         void registerPodcastSettings( const TQString &title, const PodcastSettings *settings );
 
@@ -136,7 +137,7 @@ class PlaylistBrowser : public TQVBox
         void loadDynamicItems();
 
     private:
-        PlaylistBrowser( const char* name=0 );
+        LIBAMAROK_EXPORT PlaylistBrowser( const char* name=0 );
         void polish();
 
         bool m_polished;
@@ -192,7 +193,7 @@ class PlaylistBrowser : public TQVBox
 
         static KURL::List recurse( const KURL &url );
 
-        static PlaylistBrowser *s_instance;
+        LIBAMAROK_EXPORT static PlaylistBrowser *s_instance;
 
         PlaylistCategory    *m_playlistCategory;
         PlaylistCategory    *m_streamsCategory;
