@@ -974,7 +974,7 @@ void PlaylistItem::imageTransparency( TQImage& image, float factor ) //static
     uint *data = reinterpret_cast<unsigned int *>( image.bits() );
     const int pixels = image.width() * image.height();
     uint table[256];
-    register int c;
+    int c;
 
     // Precalculate lookup table
     for( int i = 0; i < 256; ++i ) {
