@@ -37,7 +37,7 @@
 #include <tqtextstream.h> //::loadPlaylist()
 
 #include <dcopref.h>
-#include <kapplication.h>
+#include <tdeapplication.h>
 #include <kurl.h>
 
 
@@ -969,9 +969,9 @@ PlaylistFile::loadSMIL( TQTextStream &stream )
 
 /// @class RemotePlaylistFetcher
 
-#include <ktempfile.h>
-#include <kio/job.h>
-#include <klocale.h>
+#include <tdetempfile.h>
+#include <tdeio/job.h>
+#include <tdelocale.h>
 
 RemotePlaylistFetcher::RemotePlaylistFetcher( const KURL &source, TQListViewItem *after, int options )
         : TQObject( Playlist::instance()->qscrollview() )
@@ -987,7 +987,7 @@ RemotePlaylistFetcher::RemotePlaylistFetcher( const KURL &source, TQListViewItem
 
     m_destination.setPath( m_temp->name() );
 
-    KIO::Job *job = KIO::file_copy( m_source, m_destination,
+    TDEIO::Job *job = TDEIO::file_copy( m_source, m_destination,
             -1,      /* permissions, this means "do what you think" */
             true,    /* overwrite */
             false,   /* resume download */
@@ -996,7 +996,7 @@ RemotePlaylistFetcher::RemotePlaylistFetcher( const KURL &source, TQListViewItem
     Amarok::StatusBar::instance()->newProgressOperation( job )
             .setDescription( i18n("Retrieving Playlist") );
 
-    connect( job, TQT_SIGNAL(result( KIO::Job* )), TQT_SLOT(result( KIO::Job* )) );
+    connect( job, TQT_SIGNAL(result( TDEIO::Job* )), TQT_SLOT(result( TDEIO::Job* )) );
 
     Playlist::instance()->lock();
 }
@@ -1009,7 +1009,7 @@ RemotePlaylistFetcher::~RemotePlaylistFetcher()
 }
 
 void
-RemotePlaylistFetcher::result( KIO::Job *job )
+RemotePlaylistFetcher::result( TDEIO::Job *job )
 {
     if( job->error() ) {
         error() << "Couldn't download remote playlist\n";
