@@ -5,7 +5,7 @@
 #define AMAROK_REFRESHIMAGES_H
 
 #include <tqobject.h>
-namespace KIO {
+namespace TDEIO {
     class StoredTransferJob;
     class Job;
 }
@@ -26,12 +26,12 @@ class JobInfo
 class RefreshImages : public TQObject
 {
     Q_OBJECT
-  TQ_OBJECT
+  
   public:
     RefreshImages();
   private slots:
-    void finishedXmlFetch( KIO::Job* );
-    void finishedImageFetch( KIO::Job* );
+    void finishedXmlFetch( TDEIO::Job* );
+    void finishedImageFetch( TDEIO::Job* );
   private:
     static TQString localeToTLD(const TQString& locale);
     TQMap<TQString, JobInfo> m_jobInfo;
