@@ -15,7 +15,7 @@
 
 #include <kcombobox.h>
 #include <klineedit.h>
-#include <klocale.h>
+#include <tdelocale.h>
 #include <kmountpoint.h>
 #include <knuminput.h>
 
