@@ -7,6 +7,7 @@
 #define AMAROK_TAGDIALOG_H
 
 #include "config.h"
+#include "amarok_export.h"
 
 #include "htmlview.h"
 #include "ktrm.h"
@@ -33,16 +34,16 @@ namespace TagLib {
 class TagDialog : public TagDialogBase
 {
     Q_OBJECT
-  
+
 
     public:
 
         enum Changes { NOCHANGE=0, SCORECHANGED=1, TAGSCHANGED=2, LYRICSCHANGED=4, RATINGCHANGED=8, LABELSCHANGED=16 };
         enum Tabs { SUMMARYTAB, TAGSTAB, LYRICSTAB, STATSTAB, LABELSTAB };
 
-        TagDialog( const KURL& url, TQWidget* parent = 0 );
-        TagDialog( const KURL::List list, TQWidget* parent = 0 );
-        TagDialog( const MetaBundle& mb, PlaylistItem* item, TQWidget* parent = 0 );
+        LIBAMAROK_EXPORT TagDialog( const KURL& url, TQWidget* parent = 0 );
+        LIBAMAROK_EXPORT TagDialog( const KURL::List list, TQWidget* parent = 0 );
+        LIBAMAROK_EXPORT TagDialog( const MetaBundle& mb, PlaylistItem* item, TQWidget* parent = 0 );
         ~TagDialog();
 
         void setTab( int id );
